==> kyman-0.1.10.tar.gz: kyman-0.1.10/kyman/cli.py <==
"""Console script for kyman."""
import logging
import os
import sys
from argparse import ArgumentParser

from . import __version__, kyman

filename = os.path.basename(__file__)[:-3]

logger = logging.getLogger(filename)


def create_parser():
    parser = ArgumentParser(
        description="Python Tools for Kafka object management"
    )
    parser.add_argument(
        "-v",
        "--version",
        help="print the kyman version number and exit",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "--dry-run",
        help="Do not execute commands, just output the requests",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-k",
        "--insecure",
        help="Allow unverified HTTPS request to host",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-o",
        "--output-format",
        help="Output format (json, yaml)",
        nargs=1,
        metavar=("OUTPUT_FORMAT"),
        choices=["json", "yaml"],
        action="store",
        required=False,
        type=str,
        default="json",
    )
    return parser


def override_env_vars(args, env_vars):
    for env_var in env_vars:
        env_config = os.getenv(env_var)
        if env_config:
            logger.warning(f"Environment variable '{env_var}' will be overwritten")
            os.environ[env_var] = str(getattr(args, env_var.lower()))


def main():
    """Console script for kyman."""
    parser = create_parser()
    # if this method is called directly by a test case,
    logger.debug(f"parser.prog: {parser.prog}")
    if parser.prog != os.path.basename(__file__):
        ## then use --dry-run argument
        args = parser.parse_args(["--dry-run"])
    else:
        ## otherwise use no arguments
        args = parser.parse_args()
    logger.debug(f"args: {args}")
    if args.version:
        print(f"Kyman {__version__}")
        return 0
    override_env_vars(args, ["DRY_RUN", "INSECURE", "OUTPUT_FORMAT"])
    return kyman.main()


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover

==> kyman-0.1.15.tar.gz: kyman-0.1.15/kyman/cli.py <==
"""Console script for kyman."""
import logging
import os
import sys
from argparse import ArgumentParser

from . import __version__, kyman

filename = os.path.basename(__file__)[:-3]

logger = logging.getLogger(filename)


def create_parser():
    parser = ArgumentParser(description="Python Tools for Kafka object management")
    parser.add_argument(
        "-v",
        "--version",
        help="print the kyman version number and exit",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "--dry-run",
        help="Do not execute commands, just output the requests",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-k",
        "--insecure",
        help="Allow unverified HTTPS request to host",
        action="store_true",
        default=False,
    )
    parser.add_argument(
        "-o",
        "--output-format",
        help="Output format (json, yaml)",
        nargs=1,
        metavar=("OUTPUT_FORMAT"),
        choices=["json", "yaml"],
        action="store",
        required=False,
        type=str,
        default="json",
    )
    return parser


def move_args_to_env_vars(args, vars):
    for var in vars:
        value = os.getenv(var)
        if value:
            logger.warning(f"Environment variable '{var}' will be overwritten")
        attr = getattr(args, var.lower())
        attr_value = attr[0] if isinstance(attr, list) else str(attr)
        os.environ[var] = attr_value


def main():
    """Console script for kyman."""
    parser = create_parser()
    # if this method is called directly by a test case,
    logger.debug(f"parser.prog: {parser.prog}")
    if parser.prog in ["kyman", f"{os.path.basename(__file__)}"]:
        ## then use no arguments
        args = parser.parse_args()
    else:
        ## otherwise use --dry-run argument
        args = parser.parse_args(["--dry-run"])
    logger.debug(f"args: {args}")
    if args.version:
        print(f"Kyman {__version__}")
        return 0
    move_args_to_env_vars(args, ["DRY_RUN", "INSECURE", "OUTPUT_FORMAT"])
    return kyman.main()


if __name__ == "__main__":
    sys.exit(main())  # pragma: no cover
